@@ -38,6 +38,9 @@ log = logging.getLogger(__name__)
 
 from guake.globals import NAME
 from guake.globals import bindtextdomain
+from guake.support import print_support
+from guake.utils import restore_preferences
+from guake.utils import save_preferences
 
 # When we are in the document generation on readthedocs, we do not have paths.py generated
 try:
@@ -268,6 +271,30 @@ def main():
         help=_('Do not execute the start up script')
     )
 
+    parser.add_option(
+        '--save-preferences',
+        dest='save_preferences',
+        action='store',
+        default=None,
+        help=_('Save Guake preferences to this filename')
+    )
+
+    parser.add_option(
+        '--restore-preferences',
+        dest='restore_preferences',
+        action='store',
+        default=None,
+        help=_('Restore Guake preferences from this file')
+    )
+
+    parser.add_option(
+        '--support',
+        dest='support',
+        action='store_true',
+        default=False,
+        help=_('Show support infomations')
+    )
+
     # checking mandatory dependencies
     import gi
 
@@ -302,6 +329,19 @@ def main():
         print('Gtk: {}'.format(gtk_version()))
         sys.exit(0)
 
+    if options.save_preferences and options.restore_preferences:
+        parser.error('options --save-preferences and --restore-preferences are mutually exclusive')
+    if options.save_preferences:
+        save_preferences(options.save_preferences)
+        sys.exit(0)
+    elif options.restore_preferences:
+        restore_preferences(options.restore_preferences)
+        sys.exit(0)
+
+    if options.support:
+        print_support()
+        sys.exit(0)
+
     import dbus
 
     from guake.dbusiface import DBUS_NAME
@@ -348,11 +388,11 @@ def main():
 
     if options.show_preferences:
         remote_object.show_prefs()
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.new_tab:
         remote_object.add_tab(options.new_tab)
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.select_tab:
         selected = int(options.select_tab)
@@ -361,56 +401,56 @@ def main():
             remote_object.select_tab(selected)
         else:
             sys.stderr.write('invalid index: %d\n' % selected)
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.selected_tab:
         selected = remote_object.get_selected_tab()
         sys.stdout.write('%d\n' % selected)
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.selected_tablabel:
         selectedlabel = remote_object.get_selected_tablabel()
         sys.stdout.write('%s\n' % selectedlabel)
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.split_vertical:
         remote_object.v_split_current_terminal()
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.split_horizontal:
         remote_object.h_split_current_terminal()
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.command:
         remote_object.execute_command(options.command)
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.tab_index and options.rename_tab:
         try:
             remote_object.rename_tab_uuid(str(uuid.UUID(options.tab_index)), options.rename_tab)
         except ValueError:
             remote_object.rename_tab(int(options.tab_index), options.rename_tab)
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.bgcolor:
         remote_object.set_bgcolor(options.bgcolor)
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.fgcolor:
         remote_object.set_fgcolor(options.fgcolor)
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.palette_name:
         remote_object.change_palette_name(options.palette_name)
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.rename_current_tab:
         remote_object.rename_current_tab(options.rename_current_tab)
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.show_about:
         remote_object.show_about()
-        only_show_hide = False
+        only_show_hide = options.show
 
     if options.quit:
         try:
